# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .spam_assassin_rule import SpamAssassinRule
from .spam_filter_results import SpamFilterResults
from .spam_analysis_result import SpamAnalysisResult
from .mailosaur_error import MailosaurError, MailosaurException
from .message_address import MessageAddress
from .link import Link
from .image import Image
from .message_content import MessageContent
from .attachment import Attachment
from .message_header import MessageHeader
from .metadata import Metadata
from .message import Message
from .message_summary import MessageSummary
from .message_list_result import MessageListResult
from .search_criteria import SearchCriteria
from .forwarding_rule import ForwardingRule
from .server import Server
from .server_list_result import ServerListResult
from .server_create_options import ServerCreateOptions

__all__ = [
    'SpamAssassinRule',
    'SpamFilterResults',
    'SpamAnalysisResult',
    'MailosaurError', 'MailosaurException',
    'MessageAddress',
    'Link',
    'Image',
    'MessageContent',
    'Attachment',
    'MessageHeader',
    'Metadata',
    'Message',
    'MessageSummary',
    'MessageListResult',
    'SearchCriteria',
    'ForwardingRule',
    'Server',
    'ServerListResult',
    'ServerCreateOptions',
]
